@@ -54,6 +54,9 @@ class Irradiance():
     data['Time_H'] = data.index.strftime("%H").astype(float)
     data['Time_M'] = data.index.strftime("%M").astype(float)
     data['Time_S'] = data.index.strftime("%S").astype(float)
+    data['Month'] = data.index.strftime("%m").astype(float)
+    data['Day'] = data.index.strftime("%d").astype(float)
+
 
     new_index = data.index.map(lambda t: t.replace(year=2030))
     data=data.set_index(new_index)
@@ -61,10 +64,14 @@ class Irradiance():
 
 
 
-    df_both = pd.date_range("2030-01-01 00:00:00", "2030-12-31 23:00:00", freq='30T').to_frame()
+    df_both = pd.date_range("2030-01-01 00:00:00", "2030-12-31 23:00:00", freq='5T').to_frame()
     df_both = df_both.drop([0], axis=1)
     df_both = df_both.merge(data, left_index=True, right_index=True, how='left')
-    data = df_both.interpolate(method='spline', order=2)
+
+    df_both['Month']= df_both['Month'].fillna(method='ffill')
+    df_both['Day']= df_both['Day'].fillna(method='ffill')
+
+    data = df_both.interpolate(method='polynomial', order=2)
 
 
     DOY =  pd.DatetimeIndex(data.index.values).day_of_year
@@ -99,13 +106,14 @@ class Irradiance():
 
 
     cols = ['Rb_front', 'Rb_rear']
-    data[cols] = data[cols].clip(upper=1)
+    data[cols] = data[cols].clip(upper=5)
     
     data[['GHI', 'DHI','DNI']] = data[['GHI', 'DHI','DNI']].clip(lower=0)
 
 
     data['DOY'] = DOY
     data['Solar Zenith angle'] = psi
+    data = data.fillna(0)
     
 
     return inputs ,data, metadata
